.. pancad documentation master file, created by
   sphinx-quickstart on Sat Dec  7 12:27:19 2024.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

pancad documentation
==========================

**pancad** is a Python library for makers to generate, read, and convert CAD 
files and their associated information to any other file format.

.. note::
    
    This project is under active development.

.. toctree::
    :caption: Table of Contents
    :maxdepth: 2
    :glob:
    
    usage
    filetypes/*
    geometry/*
    utilities/*